==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/SplineFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineFragmentBaseDescriptionMetadata } from "./SplineFragmentBaseDescriptionMetadata";
import { SplineFragmentDescription } from "./SplineFragmentDescription";
/**
 * @hidden
 */
var SplineFragmentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SplineFragmentDescriptionMetadata, _super);
    function SplineFragmentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SplineFragmentDescriptionMetadata.b = function (a) {
        if (SplineFragmentDescriptionMetadata.a == null) {
            SplineFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SplineFragmentDescriptionMetadata.c(SplineFragmentDescriptionMetadata.a);
        }
        if (a.g(SplineFragmentDescriptionMetadata.a)) {
            return;
        }
        a.s(SplineFragmentDescriptionMetadata.a);
    };
    SplineFragmentDescriptionMetadata.c = function (a) {
        SplineFragmentBaseDescriptionMetadata.c(a);
    };
    SplineFragmentDescriptionMetadata.d = function (a) {
        SplineFragmentDescriptionMetadata.b(a);
        a.u("SplineFragment", function () { return new SplineFragmentDescription(); });
        a.t("SplineFragment", SplineFragmentDescriptionMetadata.a);
    };
    SplineFragmentDescriptionMetadata.$t = markType(SplineFragmentDescriptionMetadata, 'SplineFragmentDescriptionMetadata');
    SplineFragmentDescriptionMetadata.a = null;
    return SplineFragmentDescriptionMetadata;
}(Base));
export { SplineFragmentDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/SplineFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineFragmentBaseDescriptionMetadata } from "./SplineFragmentBaseDescriptionMetadata";
import { SplineFragmentDescription } from "./SplineFragmentDescription";
/**
 * @hidden
 */
var SplineFragmentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SplineFragmentDescriptionMetadata, _super);
    function SplineFragmentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SplineFragmentDescriptionMetadata.b = function (a) {
        if (SplineFragmentDescriptionMetadata.a == null) {
            SplineFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SplineFragmentDescriptionMetadata.c(SplineFragmentDescriptionMetadata.a);
        }
        if (a.j(SplineFragmentDescriptionMetadata.a)) {
            return;
        }
        a.y(SplineFragmentDescriptionMetadata.a);
    };
    SplineFragmentDescriptionMetadata.c = function (a) {
        SplineFragmentBaseDescriptionMetadata.c(a);
    };
    SplineFragmentDescriptionMetadata.d = function (a) {
        SplineFragmentDescriptionMetadata.b(a);
        a.aa("SplineFragment", function () { return new SplineFragmentDescription(); });
        a.z("SplineFragment", SplineFragmentDescriptionMetadata.a);
    };
    SplineFragmentDescriptionMetadata.$t = markType(SplineFragmentDescriptionMetadata, 'SplineFragmentDescriptionMetadata');
    SplineFragmentDescriptionMetadata.a = null;
    return SplineFragmentDescriptionMetadata;
}(Base));
export { SplineFragmentDescriptionMetadata };
